@@ -20,6 +20,7 @@ class HTTPModes(StrEnum):
 
 
 class RuntimeModes(StrEnum):
+    auto = 'auto'
     mt = 'mt'
     st = 'st'
 
@@ -29,8 +30,14 @@ class Loops(StrEnum):
     asyncio = 'asyncio'
     rloop = 'rloop'
     uvloop = 'uvloop'
+    winloop = 'winloop'
 
 
 class TaskImpl(StrEnum):
     asyncio = 'asyncio'
     rust = 'rust'
+
+
+class SSLProtocols(StrEnum):
+    tls12 = 'tls1.2'
+    tls13 = 'tls1.3'
